=======
Credits
=======

Original Development
--------------------

* Paul O. Hayne <paul.hayne@lasp.colorado.edu>, 2017

Package Maintainer
------------------

* K.-Michael Aye <kmichael.aye@gmail.com>, 2019
